﻿using Microsoft.EntityFrameworkCore;
using Zoo.DAL.Models;

namespace Zoo.DAL;

public static class DBInitializer
{
    public static void Seed(this ModelBuilder modelBuilder)
    {
        // Zookeepers
        Guid zookeeperPavelId = Guid.NewGuid();
        Guid zookeeperPetrId = Guid.NewGuid();

        modelBuilder.Entity<Zookeeper>().HasData
        (
            new Zookeeper()
            {
                Id = zookeeperPavelId,
                Name = "Pavel Petříček",
                BadgeId = 10,
            },
            new Zookeeper()
            {
                Id = zookeeperPetrId,
                Name = "Petr Pavlíček",
                BadgeId = 585,
            }
        );

        // Animals 
        Guid animalIdCoco = Guid.NewGuid();
        Guid animalIdMelvin = Guid.NewGuid();
        Guid animalIdLeo = Guid.NewGuid();
        Guid animalIdAlan = Guid.NewGuid();

        modelBuilder.Entity<Animal>().HasData
        (
            new Animal()
            {
                Id = animalIdCoco,
                Name = "Coco the Gorilla",
                Weight = 140,
                DateOfBirth = new DateTime(2018, 10, 9),
                ZookeeperId = zookeeperPetrId
            },
             new Animal()
             {
                 Id = animalIdMelvin,
                 Name = "Melvin the Porcupine",
                 Weight = 9.5,
                 DateOfBirth = new DateTime(2019, 5, 25),
                 ZookeeperId = zookeeperPetrId
             },
              new Animal()
              {
                  Id = animalIdLeo,
                  Name = "Leo the Giraffe",
                  Weight = 1320,
                  DateOfBirth = new DateTime(2015, 5, 2),
                  ZookeeperId = zookeeperPavelId
              },
             new Animal()
             {
                 Id = animalIdAlan,
                 Name = "Alan the Crocodile",
                 Weight = 1050,
                 DateOfBirth = new DateTime(2010, 12, 25),
                 ZookeeperId = zookeeperPavelId
             }
        );

        Guid sponsorGuid = Guid.NewGuid();

        modelBuilder.Entity<Sponsor>().HasData
        (
            new Sponsor()
            {
                Id = sponsorGuid,
                Name = "Milan Bezdíček"
            }
        );

        modelBuilder.Entity<Sponsorship>().HasData
        (
            new Sponsorship()
            {
                Id = Guid.NewGuid(),
                MonthlyAmount = 25000,
                IsActive = true,
                AnimalId = animalIdMelvin,
                SponsorId = sponsorGuid
            },
             new Sponsorship()
             {
                 Id = Guid.NewGuid(),
                 MonthlyAmount = 10000,
                 IsActive = true,
                 AnimalId = animalIdLeo,
                 SponsorId = sponsorGuid
             }
        );

    }

}
