﻿using Microsoft.EntityFrameworkCore.Migrations;

#nullable disable

namespace Zoo.DAL.Migrations
{
    public partial class Initial : Migration
    {
        protected override void Up(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.CreateTable(
                name: "Sponsor",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    Name = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Sponsor", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "Zookeeper",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    Name = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false),
                    BadgeId = table.Column<int>(type: "int", nullable: false)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Zookeeper", x => x.Id);
                });

            migrationBuilder.CreateTable(
                name: "Animal",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    Name = table.Column<string>(type: "nvarchar(50)", maxLength: 50, nullable: false),
                    DateOfBirth = table.Column<DateTime>(type: "datetime2", nullable: false),
                    Weight = table.Column<double>(type: "float", nullable: true),
                    ZookeeperId = table.Column<Guid>(type: "uniqueidentifier", nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Animal", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Animal_Zookeeper_ZookeeperId",
                        column: x => x.ZookeeperId,
                        principalTable: "Zookeeper",
                        principalColumn: "Id");
                });

            migrationBuilder.CreateTable(
                name: "Sponsorship",
                columns: table => new
                {
                    Id = table.Column<Guid>(type: "uniqueidentifier", nullable: false),
                    MonthlyAmount = table.Column<decimal>(type: "decimal(10,2)", nullable: false),
                    IsActive = table.Column<bool>(type: "bit", nullable: false),
                    AnimalId = table.Column<Guid>(type: "uniqueidentifier", nullable: true),
                    SponsorId = table.Column<Guid>(type: "uniqueidentifier", nullable: true)
                },
                constraints: table =>
                {
                    table.PrimaryKey("PK_Sponsorship", x => x.Id);
                    table.ForeignKey(
                        name: "FK_Sponsorship_Animal_AnimalId",
                        column: x => x.AnimalId,
                        principalTable: "Animal",
                        principalColumn: "Id");
                    table.ForeignKey(
                        name: "FK_Sponsorship_Sponsor_SponsorId",
                        column: x => x.SponsorId,
                        principalTable: "Sponsor",
                        principalColumn: "Id");
                });

            migrationBuilder.InsertData(
                table: "Sponsor",
                columns: new[] { "Id", "Name" },
                values: new object[] { new Guid("5b50894e-bbf5-4cac-8a5d-74798833c1ee"), "Milan Bezdíček" });

            migrationBuilder.InsertData(
                table: "Zookeeper",
                columns: new[] { "Id", "BadgeId", "Name" },
                values: new object[] { new Guid("094fa045-2aca-43db-bd74-1df81e2aae61"), 585, "Petr Pavlíček" });

            migrationBuilder.InsertData(
                table: "Zookeeper",
                columns: new[] { "Id", "BadgeId", "Name" },
                values: new object[] { new Guid("0e9898bb-9530-4703-8e43-4d27fa5bab2f"), 10, "Pavel Petříček" });

            migrationBuilder.InsertData(
                table: "Animal",
                columns: new[] { "Id", "DateOfBirth", "Name", "Weight", "ZookeeperId" },
                values: new object[,]
                {
                    { new Guid("2c6d1ca8-e85a-4464-823c-f7daf07994a7"), new DateTime(2015, 5, 2, 0, 0, 0, 0, DateTimeKind.Unspecified), "Leo the Giraffe", 1320.0, new Guid("0e9898bb-9530-4703-8e43-4d27fa5bab2f") },
                    { new Guid("7365e4c6-8ad9-424d-8503-6c6b747923b5"), new DateTime(2010, 12, 25, 0, 0, 0, 0, DateTimeKind.Unspecified), "Alan the Crocodile", 1050.0, new Guid("0e9898bb-9530-4703-8e43-4d27fa5bab2f") },
                    { new Guid("b3b19f7f-d20f-476f-a9a4-fd600bf0b025"), new DateTime(2018, 10, 9, 0, 0, 0, 0, DateTimeKind.Unspecified), "Coco the Gorilla", 140.0, new Guid("094fa045-2aca-43db-bd74-1df81e2aae61") },
                    { new Guid("e1ac2815-3cdf-47fa-acad-bdddb7233b34"), new DateTime(2019, 5, 25, 0, 0, 0, 0, DateTimeKind.Unspecified), "Melvin the Porcupine", 9.5, new Guid("094fa045-2aca-43db-bd74-1df81e2aae61") }
                });

            migrationBuilder.InsertData(
                table: "Sponsorship",
                columns: new[] { "Id", "AnimalId", "IsActive", "MonthlyAmount", "SponsorId" },
                values: new object[] { new Guid("62f0c3a3-1a46-48fe-ac66-e893473ee57e"), new Guid("e1ac2815-3cdf-47fa-acad-bdddb7233b34"), true, 25000m, new Guid("5b50894e-bbf5-4cac-8a5d-74798833c1ee") });

            migrationBuilder.InsertData(
                table: "Sponsorship",
                columns: new[] { "Id", "AnimalId", "IsActive", "MonthlyAmount", "SponsorId" },
                values: new object[] { new Guid("cf0a27cf-fae3-4649-85a7-c0c5670f0b47"), new Guid("2c6d1ca8-e85a-4464-823c-f7daf07994a7"), true, 10000m, new Guid("5b50894e-bbf5-4cac-8a5d-74798833c1ee") });

            migrationBuilder.CreateIndex(
                name: "IX_Animal_ZookeeperId",
                table: "Animal",
                column: "ZookeeperId");

            migrationBuilder.CreateIndex(
                name: "IX_Sponsorship_AnimalId",
                table: "Sponsorship",
                column: "AnimalId");

            migrationBuilder.CreateIndex(
                name: "IX_Sponsorship_SponsorId",
                table: "Sponsorship",
                column: "SponsorId");
        }

        protected override void Down(MigrationBuilder migrationBuilder)
        {
            migrationBuilder.DropTable(
                name: "Sponsorship");

            migrationBuilder.DropTable(
                name: "Animal");

            migrationBuilder.DropTable(
                name: "Sponsor");

            migrationBuilder.DropTable(
                name: "Zookeeper");
        }
    }
}
