﻿using Microsoft.EntityFrameworkCore;
using Zoo.DAL.Models;

namespace Zoo.DAL.Repository
{
    public class GenericRepository<TEntity> : IGenericRepository<TEntity> where TEntity : BaseEntity
    {
        private ZooDbContext _dbContext;
        private DbSet<TEntity> _dbSet;

        public GenericRepository(ZooDbContext dbContext)
        {
            _dbContext = dbContext;
            _dbSet = _dbContext.Set<TEntity>();
        }

        public async Task Delete(Guid idToDelete)
        {
            var entityToDelete = await _dbSet.FindAsync(idToDelete);

            if (_dbContext.Entry(entityToDelete).State == EntityState.Detached)
            {
                _dbContext.Attach(entityToDelete);
            }

            _dbSet.Remove(entityToDelete);
        }

        public async Task<IEnumerable<TEntity>> Get()
        {
            return await _dbSet.ToListAsync();
        }

        public async Task<TEntity> GetById(Guid id)
        {
            return await _dbSet.FindAsync(id);
        }

        public async Task Insert(TEntity entity)
        {
            await _dbSet.AddAsync(entity);
        }

        public void Update(TEntity entity)
        {
            _dbSet.Attach(entity);
            _dbContext.Entry(entity).State = EntityState.Modified;
        }

        public async Task Save()
        {
            await _dbContext.SaveChangesAsync();
        }


        public async ValueTask DisposeAsync()
        {
            await _dbContext.DisposeAsync();
        }

    }
}
