﻿using Zoo.DAL.Models;
using Zoo.DAL.Repository;

namespace Zoo.DAL.UnitOfWork
{
    public class UnitOfWork : IUnitOfWork
    {
        private ZooDbContext _dbContext;

        public IGenericRepository<Animal> AnimalRepository { get; }

        public IGenericRepository<Zookeeper> ZookeeperRepository { get; }

        public IGenericRepository<Sponsor> SponsorRepository { get; }

        public IGenericRepository<Sponsorship> SponsorshipRepository { get; }

        public UnitOfWork()
        {
            _dbContext = new ZooDbContext();
            AnimalRepository = new GenericRepository<Animal>(_dbContext);
            ZookeeperRepository = new GenericRepository<Zookeeper>(_dbContext);
            SponsorRepository = new GenericRepository<Sponsor>(_dbContext);
            SponsorshipRepository = new GenericRepository<Sponsorship>(_dbContext);
        }

        public async Task CommitAsync()
        {
            await _dbContext.SaveChangesAsync();
        }

        public async ValueTask DisposeAsync()
        {
            await _dbContext.DisposeAsync();
        }
    }
}
